
import Downloads from './Downloads.js';
import GetCopy from './GetCopy.js';

export default {
    components: { Downloads, GetCopy },
    props: [ 'cluster', 'token', 'state' ],
    data() {
        return {
            sshSignReq: {
                PubKey: "",
                Principal: "root",
                Validity: "+1d",
            },
            sshUserCert: null,
        };
    },
    methods: {
        sshCASign() {
            event.preventDefault();
            fetch(`/clusters/${this.cluster.Name}/ssh/user-ca/sign`, {
                method: 'POST',
                body: JSON.stringify(this.sshSignReq),
                headers: { 'Authorization': 'Bearer ' + this.token, 'Content-Type': 'application/json' },
            }).then((resp) => resp.blob())
              .then((cert) => { this.sshUserCert = URL.createObjectURL(cert) })
              .catch((e) => { alert('failed to sign: '+e); })
        },
    },
    template: `
  <h3>Tokens</h3>
  <section class="links">
    <GetCopy v-for="n in cluster.Tokens" :token="token" :name="n" :href="'/clusters/'+cluster.Name+'/tokens/'+n" />
  </section>

  <h3>Passwords</h3>
  <section class="links">
    <GetCopy v-for="n in cluster.Passwords" :token="token" :name="n" :href="'/clusters/'+cluster.Name+'/passwords/'+n" />
  </section>

  <h3>Downloads</h3>
  <Downloads :token="token" :state="state" kind="cluster" :name="cluster.Name" />

  <h3>CAs</h3>
  <table><tr><th>Name</th><th>Certificate</th><th>Signed certificates</th></tr>
  <tr v-for="ca in cluster.CAs">
    <td>{{ ca.Name }}</td>
    <td><GetCopy :token="token" name="cert" :href="'/clusters/'+cluster.Name+'/CAs/'+ca.Name+'/certificate'" /></td>
    <td><template v-for="signed in ca.Signed">
      {{" "}}
      <GetCopy :token="token" :name="signed" :href="'/clusters/'+cluster.Name+'/CAs/'+ca.Name+'/signed?name='+signed" />
    </template></td>
  </tr></table>

  <h3>SSH</h3>
  <form @submit="sshCASign()" action="">
    <p>User public key (OpenSSH format):<br/>
       <textarea v-model="sshSignReq.PubKey"></textarea>
    </p>
    <p>Principal: <input type="text" v-model="sshSignReq.Principal"/></p>
    <p>Validity: <input type="text" v-model="sshSignReq.Validity"/></p>
    <input type="submit" value="Sign key" />
  </form>
  <p v-if="sshUserCert">
    <a :href="sshUserCert" download="ssh-cert.pub">Get user SSH certificate</a>
  </p>
`
}
